==> senior_design_system-0.17.0.tar.gz: lib/components/senior_checkbox/senior_checkbox_widget.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_checkbox_style.dart';
import '../../themes/senior_theme_provider.dart';
import '../../themes/senior_theme.dart';

class SeniorCheckbox extends StatelessWidget {
  const SeniorCheckbox({
    Key? key,
    this.actionOnTitle = false,
    this.disabled = false,
    this.extraTapMargin = 0,
    required this.onChanged,
    this.style,
    this.title,
    required this.value,
  }) : super(key: key);

  final bool actionOnTitle;
  final bool disabled;
  final double extraTapMargin;
  final Function(bool?)? onChanged;
  final SeniorCheckboxStyle? style;
  final String? title;
  final bool value;

  static const double size = Checkbox.width;

  void _handleValueChange() {
    if (!disabled && onChanged != null) {
      onChanged!(!value);
    }
  }

  Widget _buildCheckbox(SeniorTheme? theme, SeniorTheme defaultTheme) {
    return Container(
      width: SeniorCheckbox.size,
      height: SeniorCheckbox.size,
      decoration: BoxDecoration(
        color: SeniorColors.pureWhite,
        border: Border.all(
          color: disabled
              ? style?.disabledBorderColor ??
                  theme?.checkboxTheme?.style?.disabledBorderColor ??
                  defaultTheme.checkboxTheme?.style?.disabledBorderColor ??
                  SeniorColors.secondaryColor300
              : value
                  ? style?.checkedBorderColor ??
                      theme?.checkboxTheme?.style?.checkedBorderColor ??
                      defaultTheme.checkboxTheme?.style?.uncheckedBorderColor ??
                      SeniorColors.primaryColor
                  : style?.uncheckedBorderColor ??
                      theme?.checkboxTheme?.style?.uncheckedBorderColor ??
                      defaultTheme.checkboxTheme?.style?.uncheckedBorderColor ??
                      SeniorColors.secondaryColor600,
          width: 1,
        ),
        borderRadius: BorderRadius.circular(3),
      ),
      child: Theme(
        data: ThemeData(
          unselectedWidgetColor: Colors.transparent,
          disabledColor: Colors.transparent,
        ),
        child: Checkbox(
          value: value,
          onChanged: null,
          activeColor: Colors.transparent,
          checkColor: disabled
              ? style?.checkColor ??
                  theme?.checkboxTheme?.style?.checkColor ??
                  defaultTheme.checkboxTheme?.style?.checkColor ??
                  SeniorColors.secondaryColor300
              : style?.disabledCheckColor ??
                  theme?.checkboxTheme?.style?.checkColor ??
                  defaultTheme.checkboxTheme?.style?.checkColor ??
                  SeniorColors.primaryColor,
          materialTapTargetSize: MaterialTapTargetSize.shrinkWrap,
        ),
      ),
    );
  }

  Widget _buildTitle(SeniorTheme? theme, SeniorTheme defaultTheme) {
    return title != null
        ? Text(
            title!,
            style: SeniorTypography.text(
              color: disabled
                  ? style?.disabledTitleColor ??
                      theme?.checkboxTheme?.style?.disabledTitleColor ??
                      defaultTheme.checkboxTheme?.style?.disabledTitleColor ??
                      SeniorColors.secondaryColor300
                  : style?.titleColor ??
                      theme?.checkboxTheme?.style?.titleColor ??
                      defaultTheme.checkboxTheme?.style?.titleColor ??
                      SeniorColors.neutralColor900,
            ),
          )
        : SizedBox.shrink();
  }

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    return ListTileTheme.merge(
      child: Stack(
        alignment: Alignment.centerLeft,
        children: [
          GestureDetector(
            onTap: actionOnTitle ? _handleValueChange : null,
            child: Row(
              children: [
                SizedBox(
                  width: extraTapMargin,
                ),
                Padding(
                  padding: title != null ? const EdgeInsets.only(right: SeniorSpacing.xsmall) : EdgeInsets.all(0),
                  child: _buildCheckbox(theme, defaultTheme),
                ),
                _buildTitle(theme, defaultTheme),
              ],
            ),
          ),
          GestureDetector(
            onTap: _handleValueChange,
            child: Container(
              color: Colors.transparent,
              width: extraTapMargin + size + extraTapMargin,
              height: extraTapMargin + size + extraTapMargin,
            ),
          ),
        ],
      ),
    );
  }
}

==> senior_design_system-0.21.4.tar.gz: lib/components/senior_checkbox/senior_checkbox_widget.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_checkbox_style.dart';
import '../../themes/senior_theme_provider.dart';
import '../../themes/senior_theme.dart';

class SeniorCheckbox extends StatelessWidget {
  /// Creates the SDS checkbox component.
  ///
  /// The [onChanged] and [value] parameters are required.
  const SeniorCheckbox({
    Key? key,
    this.actionOnTitle = false,
    this.disabled = false,
    this.extraTapMargin = 0,
    required this.onChanged,
    this.style,
    this.title,
    required this.value,
  }) : super(key: key);

  /// Allows the checkbox title to also perform the action of changing the value.
  ///
  /// The default value is false.
  final bool actionOnTitle;

  /// Defines whether the checkbox will be disabled.
  ///
  /// The default value is false.
  final bool disabled;

  /// A margin that allows you to increase the area of interaction of the checkbox.
  ///
  /// The default value is 0.
  final double extraTapMargin;

  /// A função callback que é executada quando o valor do checkbox é alterado.
  final Function(bool?)? onChanged;

  /// The component's style definitions.
  /// Allows you to configure:
  /// [SeniorCheckboxStyle.activeColor] The color to use when this checkbox is checked.
  /// [SeniorCheckboxStyle.checkColor] The color to use for the check icon when this checkbox is checked.
  /// [SeniorCheckboxStyle.checkedBorderColor] The color of the checkbox border.
  /// [SeniorCheckboxStyle.disabledBorderColor] The border color of the checkbox when disabled.
  /// [SeniorCheckboxStyle.disabledCheckColor] The color to use for the check icon when this checkbox is checked and it is
  /// disabled.
  /// [SeniorCheckboxStyle.disabledTitleColor] The color of the checkbox title when disabled.
  /// [SeniorCheckboxStyle.titleColor] The color of the checkbox title.
  /// [SeniorCheckboxStyle.uncheckedBorderColor] The color of the checkbox border when it is not checked.
  final SeniorCheckboxStyle? style;

  /// The title of the checkbox.
  final String? title;

  /// The value passed to the [value] parameters of the internal [Checkbox].
  /// Whether this checkbox is checked.
  final bool value;

  static const double size = Checkbox.width;

  void _handleValueChange() {
    if (!disabled && onChanged != null) {
      onChanged!(!value);
    }
  }

  Widget _buildCheckbox(SeniorTheme? theme, SeniorTheme defaultTheme) {
    return Container(
      width: SeniorCheckbox.size,
      height: SeniorCheckbox.size,
      decoration: BoxDecoration(
        color: SeniorColors.pureWhite,
        border: Border.all(
          color: disabled
              ? style?.disabledBorderColor ??
                  theme?.checkboxTheme?.style?.disabledBorderColor ??
                  defaultTheme.checkboxTheme?.style?.disabledBorderColor ??
                  SeniorColors.secondaryColor300
              : value
                  ? style?.checkedBorderColor ??
                      theme?.checkboxTheme?.style?.checkedBorderColor ??
                      defaultTheme.checkboxTheme?.style?.uncheckedBorderColor ??
                      SeniorColors.primaryColor
                  : style?.uncheckedBorderColor ??
                      theme?.checkboxTheme?.style?.uncheckedBorderColor ??
                      defaultTheme.checkboxTheme?.style?.uncheckedBorderColor ??
                      SeniorColors.secondaryColor600,
          width: 1,
        ),
        borderRadius: BorderRadius.circular(3),
      ),
      child: Theme(
        data: ThemeData(
          unselectedWidgetColor: Colors.transparent,
          disabledColor: Colors.transparent,
        ),
        child: Checkbox(
          value: value,
          onChanged: null,
          activeColor: Colors.transparent,
          checkColor: disabled
              ? style?.checkColor ??
                  theme?.checkboxTheme?.style?.checkColor ??
                  defaultTheme.checkboxTheme?.style?.checkColor ??
                  SeniorColors.secondaryColor300
              : style?.disabledCheckColor ??
                  theme?.checkboxTheme?.style?.checkColor ??
                  defaultTheme.checkboxTheme?.style?.checkColor ??
                  SeniorColors.primaryColor,
          materialTapTargetSize: MaterialTapTargetSize.shrinkWrap,
        ),
      ),
    );
  }

  Widget _buildTitle(SeniorTheme? theme, SeniorTheme defaultTheme) {
    return title != null
        ? Text(
            title!,
            style: SeniorTypography.text(
              color: disabled
                  ? style?.disabledTitleColor ??
                      theme?.checkboxTheme?.style?.disabledTitleColor ??
                      defaultTheme.checkboxTheme?.style?.disabledTitleColor ??
                      SeniorColors.secondaryColor300
                  : style?.titleColor ??
                      theme?.checkboxTheme?.style?.titleColor ??
                      defaultTheme.checkboxTheme?.style?.titleColor ??
                      SeniorColors.neutralColor900,
            ),
          )
        : SizedBox.shrink();
  }

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    return ListTileTheme.merge(
      child: Stack(
        alignment: Alignment.centerLeft,
        children: [
          GestureDetector(
            onTap: actionOnTitle ? _handleValueChange : null,
            child: title == null
                ? _buildCheckbox(theme, defaultTheme)
                : Row(
                    children: [
                      SizedBox(
                        width: extraTapMargin,
                      ),
                      Padding(
                        padding: title != null ? const EdgeInsets.only(right: SeniorSpacing.xsmall) : EdgeInsets.zero,
                        child: _buildCheckbox(theme, defaultTheme),
                      ),
                      _buildTitle(theme, defaultTheme),
                    ],
                  ),
            // child: _buildCheckbox(theme, defaultTheme),
          ),
          GestureDetector(
            onTap: _handleValueChange,
            child: Container(
              color: Colors.transparent,
              width: extraTapMargin + size + extraTapMargin,
              height: extraTapMargin + size + extraTapMargin,
            ),
          ),
        ],
      ),
    );
  }
}
